@@ -18,6 +18,8 @@ import subprocess
 import sys
 import re
 
+from botocore.credentials import JSONFileCache
+
 import botocore.auth
 import botocore.awsrequest
 import botocore.compat
@@ -106,6 +108,8 @@ class Context(collections.namedtuple('Context', ['session', 'repository', 'versi
     else:
       session = botocore.session.Session(event_hooks = event_handler)
 
+    session.get_component('credential_provider').get_provider('assume-role').cache = JSONFileCache()
+
     try:
       # when the aws cli is available support plugin authentication
 
